=== modified file 'lib/Controller/Region.php'
--- lib/Controller/Region.php	2018-05-18 15:42:54 +0000
+++ lib/Controller/Region.php	2018-09-04 13:59:22 +0000
@@ -123,6 +123,9 @@
             foreach ($playlist->widgets as $widget) {
                 /* @var Widget $widget */
                 $widget->module = $this->moduleFactory->createWithWidget($widget, $region);
+
+                // Augment with tags
+                $widget->tags = $widget->module->getMediaTags();
             }
         }
 

=== modified file 'lib/Widget/ModuleWidget.php'
--- lib/Widget/ModuleWidget.php	2018-07-05 15:01:44 +0000
+++ lib/Widget/ModuleWidget.php	2018-09-04 13:59:22 +0000
@@ -589,6 +589,22 @@
     }
 
     /**
+     * @return array
+     * @throws \Xibo\Exception\NotFoundException
+     */
+    final public function getMediaTags()
+    {
+        if ($this->module->regionSpecific == 0) {
+            $media = $this->mediaFactory->getById($this->widget->getPrimaryMediaId());
+            $media->load();
+
+            return $media->tags;
+        } else {
+            return [];
+        }
+    }
+
+    /**
      * Get the duration
      * @param array $options
      * @return int

=== modified file 'views/region-form-timeline.twig'
--- views/region-form-timeline.twig	2018-03-23 15:19:28 +0000
+++ views/region-form-timeline.twig	2018-09-04 13:59:22 +0000
@@ -103,12 +103,17 @@
                                                 </li>
                                             {% endif %}
                                         </ul>
-                                        <div class="timelineMediaDetails {{ coloring }}">
+                                        <div class="timelineMediaDetails {{ coloring }} {% for tag in widget.tags %}tag_{{ tag.tag }} {% endfor %}">
                                             {% if widget.useDuration %}
                                             <h3>{% trans %}{{ name }} ({{ duration }} seconds){% endtrans %}</h3>
                                             {% else %}
                                             <h3>{{ name }}</h3>
                                             {% endif %}
+                                            <div class="timelineMediaTags">
+                                            {% for tag in widget.tags %}
+                                                <span class="label label-default">{{ tag.tag }}</span>
+                                            {% endfor %}
+                                            </div>
                                         </div>
                                         <div class="timelineMediaPreview">
                                             {{ widget.module.hoverPreview()|raw }}

=== modified file 'web/theme/default/css/timeline.css'
--- web/theme/default/css/timeline.css	2016-12-15 12:33:44 +0000
+++ web/theme/default/css/timeline.css	2018-09-04 13:59:22 +0000
@@ -93,6 +93,13 @@
     padding-left: 20px;
     color: whiteSmoke;
 }
+
+div.timelineMediaDetails .timelineMediaTags {
+    float: right;
+    max-width: 250px;
+    overflow: hidden;
+}
+
 div.timelineMediaItemColouringDefault {
     background-color: green;
 }

